@@ -74,11 +74,12 @@ void IOGfxDisplayGL2::close() {
 		gl->DeleteBuffers(1, &vboSpriteVertices);
 		gl->DeleteBuffers(1, &vboSpriteTexcoords);
 		gl->DeleteBuffers(1, &vboCroppedSpriteTexcoords);
+		gl->Clear(GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT|GL_STENCIL_BUFFER_BIT);
 		delete gl;
 		gl = NULL;
 	}
 
-	if (glcontext) SDL_GL_DeleteContext(glcontext);
+	if (glcontext != NULL) SDL_GL_DeleteContext(glcontext);
 	glcontext = NULL;
 
 	IOGfxDisplay::close();
