@@ -2,7 +2,7 @@
  * Dink.ini - loading graphics
 
  * Copyright (C) 1997, 1998, 1999, 2002, 2003  Seth A. Robinson
- * Copyright (C) 2008  Sylvain Beucler
+ * Copyright (C) 2008, 2009, 2010, 2015  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -35,10 +35,14 @@ enum idata_type { IDATA_EMPTY=0, IDATA_SPRITE_INFO, IDATA_FRAME_SPECIAL,
 #define DINKINI_NOTANIM      0x00000004
 #define DINKINI_COMPAT_DIRFF 0x00000008
 
-extern void dinkini_init(void);
+extern void dinkini_init(int nb_idata);
 extern void dinkini_quit(void);
-extern void make_idata(enum idata_type type, int myseq, int myframe, int xoffset, int yoffset, rect crect);
-extern void program_idata(void);
-extern void load_batch(void);
+extern void load_batch(bool playmidi);
+
+extern void figure_out(char* line);
+
+extern void check_base(int base);
+extern void check_seq_status(int h);
+extern void check_frame_status(int h, int frame);
 
 #endif
